|Travis|_ |Coveralls|_ |Docs|_

.. |Travis| image:: https://api.travis-ci.org/Mortar/mortar_rdb.png?branch=master
.. _Travis: https://travis-ci.org/Mortar/mortar_rdb

.. |Coveralls| image:: https://coveralls.io/repos/Mortar/mortar_rdb/badge.png?branch=master
.. _Coveralls: https://coveralls.io/r/Mortar/mortar_rdb?branch=master

.. |Docs| image:: https://readthedocs.org/projects/mortar-rdb/badge/?version=latest
.. _Docs: http://mortar-rdb.readthedocs.org/en/latest/

mortar_rdb
==========

This package ties together `SQLAlchemy`__ and
the `component architecture`__ to make it easy to develop projects
using SQLAlchemy through their complete lifecycle.

__ http://www.sqlalchemy.org/
__ http://docs.zope.org/zope.component/narr.html

Licensing
=========

See ``docs/license.txt``.
